@@ -1,12 +1,8 @@
-# Copyright 2016 The Michael Song. All rights rberved.
-# Use of this source code is governed by a BSD-style
-# license that can be found in the LICENSE file.
-
 package Spp::Cursor;
 
 use Exporter;
 our @ISA    = qw(Exporter);
-our @EXPORT = qw(new_cursor getchar prechar nextchar);
+our @EXPORT_OK = qw(new_cursor step getchar prechar);
 
 use 5.012;
 
@@ -16,6 +12,7 @@ sub new_cursor {
    return {
       str    => $str,
       ns     => $ns,
+      len    => length($str),
       off    => 0,
       maxoff => 0,      # record max match location
       debug  => 0,      # 1 open debug mode
@@ -23,6 +20,12 @@ sub new_cursor {
    };
 }
 
+sub step {
+   my $cursor = shift;
+   $cursor->{off} += 1;
+   return 1;
+}
+
 sub getchar {
    my $cursor = shift;
    return substr($cursor->{str}, $cursor->{off}, 1);
@@ -33,9 +36,4 @@ sub prechar {
    return substr($cursor->{str}, $cursor->{off} - 1, 1);
 }
 
-sub nextchar {
-   my $cursor = shift;
-   return substr($cursor->{str}, $cursor->{off} + 1, 1);
-}
-
 1;
