@@ -3,11 +3,9 @@ package Spp::IsAtom;
 use Exporter;
 our @ISA    = qw(Exporter);
 our @EXPORT = qw(
-  is_atom is_atoms
-  is_atom_name is_false is_true is_bool
+  is_atom is_atom_name is_false is_true is_bool
   is_sym is_token is_rept is_look
-  is_tillnot is_str_atom is_int_atom is_array_atom
-  is_expr);
+  is_tillnot is_str is_expr);
 
 use Spp::Tools qw(is_perl_array is_perl_str);
 
@@ -16,18 +14,6 @@ sub is_atom {
    return (is_perl_array($x) and is_perl_str($x->[0]));
 }
 
-sub is_atoms {
-   my $pairs = shift;
-   if (is_perl_array($pairs)) {
-      for my $pair (@{$pairs}) {
-         next if is_atom($pair);
-         return 0;
-      }
-      return 1;
-   }
-   return 0;
-}
-
 sub is_atom_name {
    my ($atom, $name) = @_;
    return (is_atom($atom) and $atom->[0] eq $name);
@@ -77,16 +63,11 @@ sub is_tillnot {
    return 0;
 }
 
-sub is_str_atom {
+sub is_str {
    my $atom = shift;
    return is_atom_name($atom, 'Str');
 }
 
-sub is_array_atom {
-   my $atom = shift;
-   return is_atom_name($atom, 'Array');
-}
-
 sub is_expr {
    my $atom = shift;
    return is_atom_name($atom, 'Expr');
